nltk.corpus package
===================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   nltk.corpus.reader

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.corpus.europarl_raw
   nltk.corpus.util

Module contents
---------------

.. automodule:: nltk.corpus
   :members:
   :undoc-members:
   :show-inheritance:
